Utilities
=========

The utilities make your life easier by providing functionalities which
are repeatedly when working with the quantum gates library.


.. _utilities_functions:

Functions
---------

We use the helper functions often in the order presented here.


.. _load_config:

load_config
~~~~~~~~~~~

Coming soon.

.. _setup_backend:

setup_backend
~~~~~~~~~~~~~

Coming soon.

.. _create_qc_list:


create_qc_list
~~~~~~~~~~~~~~

Coming soon.

.. _multiprocessing_parallel_simulation:

multiprocessing_parallel_simulation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Coming soon.

.. _mock_parallel_simulation:

mock_parallel_simulation
~~~~~~~~~~~~~~~~~~~~~~~~

Coming soon.

.. _concurrent_parallel_simulation:

concurrent_parallel_simulation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Coming soon.

.. _fix_counts:

fix_counts
~~~~~~~~~~

Coming soon.

.. _post_process_split: 

post_process_split
~~~~~~~~~~~~~~~~~~

Coming soon.

.. _utilities_classes:

Classes
-------

.. _deviceparameters:

DeviceParameters
~~~~~~~~~~~~~~~~

Coming soon.
